diff --git a/MainWindow.xaml b/MainWindow.xaml
index aff8813..183c39a 100644
--- a/MainWindow.xaml
+++ b/MainWindow.xaml
@@ -1180,9 +1180,11 @@
+
+
diff --git a/Controls/DialogChrome.cs b/Controls/DialogChrome.cs
index e125eda..0e97158 100644
--- a/Controls/DialogChrome.cs
+++ b/Controls/DialogChrome.cs
@@ -67,9 +67,9 @@ namespace MmdPdf
int kp = fullTitle?.IndexOf("MmdPdf", StringComparison.Ordinal) ?? -1;
if (kp >= 0)
{
// Killer + PDF in one TextBlock so the two sizes share a baseline (cohesive wordmark).
var logoTb = new TextBlock { VerticalAlignment = VerticalAlignment.Center };
- logoTb.Inlines.Add(new System.Windows.Documents.Run("Killer") { FontFamily = wordmark, FontWeight = FontWeights.Normal, FontSize = 16, Foreground = primary });
+ logoTb.Inlines.Add(new System.Windows.Documents.Run("MMD ") { FontFamily = wordmark, FontWeight = FontWeights.Normal, FontSize = 16, Foreground = primary });
logoTb.Inlines.Add(new System.Windows.Documents.Run("PDF") { FontFamily = wordmarkPdf, FontWeight = FontWeights.Bold, FontSize = 20.8, Foreground = logo });
sp.Children.Add(logoTb);
string after = fullTitle![(kp + "MmdPdf".Length)..];
@@ -67,9 +67,9 @@ namespace MmdPdf
if (kp >= 0)
{
- // Killer + PDF in one TextBlock so the two sizes share a baseline (cohesive wordmark).
+ // MMD + PDF in one TextBlock so the two sizes share a baseline (cohesive wordmark).
var logoTb = new TextBlock { VerticalAlignment = VerticalAlignment.Center };